==> noalyss-6.7.2.0.tar.gz: noalyss-6.7.2.0/include/database.item.php <==
<?php 
$menu[]=_('Achat');  $desc[]=_('Nouvel achat ou dépense');
$menu[]=_('Historique');  $desc[]=_('Historique des imputations analytiques');
$menu[]=_('Balance simple');  $desc[]=_('Balance simple des imputations analytiques');
$menu[]=_('Tableau');  $desc[]=_('Tableau lié à la comptabilité');
$menu[]=_('Balance Analytique/comptabilité');  $desc[]=_('Lien entre comptabilité et Comptabilité analytique');
$menu[]=_('Groupe');  $desc[]=_('Balance par groupe');
$menu[]=_('TVA');  $desc[]=_('Config. de la tva');
$menu[]=_('Vente');  $desc[]=_('Nouvelle vente ou recette');
$menu[]=_('Config. Menu');  $desc[]=_('Configuration des menus et plugins');
$menu[]=_('Fournisseur');  $desc[]=_('Suivi fournisseur');
$menu[]=_('Opérations diverses');  $desc[]=_('OD analytique');
$menu[]=_('Création de rapport');  $desc[]=_('Création de rapport');
$menu[]=_('saut de ligne');  $desc[]=_('Saut de ligne');
$menu[]=_('Client');  $desc[]=_('Suivi client');
$menu[]=_('Historique stock');  $desc[]=_('Historique des mouvement de stock');
$menu[]=_('Export Historique');  
$menu[]=_('Export Journaux');  
$menu[]=_('Export Journaux');  
$menu[]=_('Export Poste détail');  
$menu[]=_('Export Poste détail');  
$menu[]=_('Export Fiche détail');  
$menu[]=_('Export Fiche détail');  
$menu[]=_('Export Fiche balance');  
$menu[]=_('Export Fiche balance');  
$menu[]=_('Export report');  
$menu[]=_('Export report');  
$menu[]=_('Export Fiche');  
$menu[]=_('Export Fiche');  
$menu[]=_('Export Grand Livre');  
$menu[]=_('Export Grand Livre');  
$menu[]=_('Export Sécurité');  
$menu[]=_('Export Comptabilité analytique');  
$menu[]=_('Export Comptabilité analytique balance simple');  
$menu[]=_('Export Comptabilité analytique');  
$menu[]=_('Export Comptabilité analytique balance double');  
$menu[]=_('Export Comptabilité analytique balance double');  
$menu[]=_('Export Balance comptable');  
$menu[]=_('Export Balance comptable');  
$menu[]=_('Export Tableau Analytique');  
$menu[]=_('Export Historique Compt. Analytique');  
$menu[]=_('Export Balance groupe analytique');  
$menu[]=_('Export Bilan');  
$menu[]=_('Impression Grand-Livre');  
$menu[]=_('Export définition d\'un raport');  
$menu[]=_('Export Action Gestion');  
$menu[]=_('Export Historique mouvement stock');  
$menu[]=_('Export Résumé list stock');  
$menu[]=_('Plan Compt. analytique');  $desc[]=_('Plan analytique');
$menu[]=_('Groupe');  $desc[]=_('Groupe analytique');
$menu[]=_('Contact');  $desc[]=_('Liste des contacts');
$menu[]=_('Extension');  $desc[]=_('Extensions (plugins)');
$menu[]=_('Ecriture prédefinie');  $desc[]=_('Gestion des opérations prédéfinifies');
$menu[]=_('Opérations Diverses');  $desc[]=_('Nouvelle opérations diverses');
$menu[]=_('Nouvel extrait');  $desc[]=_('Nouvel extrait bancaire');
$menu[]=_('Recherche');  $desc[]=_('Recherche');
$menu[]=_('Paramètre');  $desc[]=_('Module paramètre');
$menu[]=_('Catégorie de documents');  $desc[]=_('Config. catégorie de documents');
$menu[]=_('Lettrage par Fiche');  $desc[]=_('Lettrage par fiche');
$menu[]=_('Historique achat');  $desc[]=_('Historique achat');
$menu[]=_('Historique opérations diverses');  $desc[]=_('Historique opérations diverses');
$menu[]=_('Poste');  $desc[]=_('Impression du détail d\'un poste comptable');
$menu[]=_('Rapport');  $desc[]=_('Impression de rapport');
$menu[]=_('Grand Livre');  $desc[]=_('Impression du grand livre');
$menu[]=_('Balance');  $desc[]=_('Impression des balances comptables');
$menu[]=_('Achat');  $desc[]=_('Menu achat');
$menu[]=_('Menu et profil');  $desc[]=_('Menu ');
$menu[]=_('Impression');  $desc[]=_('Menu impression');
$menu[]=_('Banque');  $desc[]=_('Information Banque');
$menu[]=_('Grand\'Livre');  $desc[]=_('Grand livre analytique');
$menu[]=_('Gestion');  $desc[]=_('Module gestion');
$menu[]=_('Lettrage');  $desc[]=_('Lettrage');
$menu[]=_('Accueil');  $desc[]=_('Accueil');
$menu[]=_('Comptabilité');  $desc[]=_('Module comptabilité');
$menu[]=_('Divers');  $desc[]=_('Paramètres divers');
$menu[]=_('Sortie');  $desc[]=_('Sortie');
$menu[]=_('Profil');  $desc[]=_('Configuration profil');
$menu[]=_('Poste');  $desc[]=_('Config. poste comptable de base');
$menu[]=_('Fiche');  $desc[]=_('Liste,Balance,Historique par fiche');
$menu[]=_('Préférence');  $desc[]=_('Préférence');
$menu[]=_('Configuration étiquette');  $desc[]=_('Configuration des tags');
$menu[]=_('Balance croisée double');  $desc[]=_('Balance double croisées des imputations analytiques');
$menu[]=_('Sociétés');  $desc[]=_('Parametre societe');
$menu[]=_('Période');  $desc[]=_('Gestion des périodes');
$menu[]=_('Vérification ');  $desc[]=_('Vérification de la comptabilité');
$menu[]=_('Ecriture Ouverture');  $desc[]=_('Ecriture d\'ouverture');
$menu[]=_('Document');  $desc[]=_('Config. modèle de document');
$menu[]=_('journaux');  $desc[]=_('Configuration des journaux');
$menu[]=_('Sécurité');  $desc[]=_('configuration de la sécurité');
$menu[]=_('Attribut de fiche');  $desc[]=_('Gestion des attributs de fiches ');
$menu[]=_('Etat des stock');  $desc[]=_('Etat des stock');
$menu[]=_('Modification Stocks');  $desc[]=_('Modification des stocks (inventaire)');
$menu[]=_('Histo. Changement');  $desc[]=_('Liste des changements manuels des stocks');
$menu[]=_('Navigateur');  $desc[]=_('Menu simplifié pour retrouver rapidement un menu');
$menu[]=_('Recherche');  $desc[]=_('Recherche');
$menu[]=_('Historique');  $desc[]=_('Historique');
$menu[]=_('Rapprochement');  $desc[]=_('Rapprochement bancaire');
$menu[]=_('Soldes');  $desc[]=_('Solde des comptes en banques, caisse...');
$menu[]=_('Lettrage par Poste');  $desc[]=_('lettrage par poste comptable');
$menu[]=_('Balance');  $desc[]=_('Balance par catégorie de fiche');
$menu[]=_('Plan Comptable');  $desc[]=_('Config. du plan comptable');
$menu[]=_('Historique vente');  $desc[]=_('Historique des ventes');
$menu[]=_('Historique financier');  $desc[]=_('Historique financier');
$menu[]=_('Rapprochement');  $desc[]=_('Impression des rapprochements');
$menu[]=_('Bilan');  $desc[]=_('Impression de bilan');
$menu[]=_('Configuration des dépôts');  $desc[]=_('Configuration dépôts');
$menu[]=_('Stock');  $desc[]=_('Stock');
$menu[]=_('Catégorie de fiche');  $desc[]=_('Gestion catégorie de fiche');
$menu[]=_('Fiche');  $desc[]=_('Configuration de catégorie de fiches');
$menu[]=_('Etat des documents');  $desc[]=_('Etat des documents');
$menu[]=_('Opérations diverses');  $desc[]=_('Menu opérations diverses');
$menu[]=_('Impression Journaux');  $desc[]=_('Impression des journaux');
$menu[]=_('Vente / Recette');  $desc[]=_('Menu ventes et recettes');
$menu[]=_('Impression');  $desc[]=_('Impression compta. analytique');
$menu[]=_('Compta Analytique');  $desc[]=_('Module comptabilité analytique');
$menu[]=_('Tableau de bord');  $desc[]=_('Tableau de bord');
$menu[]=_('Avancé');  $desc[]=_('Menu avancé');
$menu[]=_('Favori');  $desc[]=_('Raccourci vers vos menus préférés');
$menu[]=_('Trésorerie');  $desc[]=_('Menu Financier');
$menu[]=_('Liste Suivi');  $desc[]=_('Document de suivi sous forme de liste');
$menu[]=_('Moyen de paiement');  $desc[]=_('Config. des méthodes de paiement');
$menu[]=_('Administration');  $desc[]=_('Suivi administration, banque');
$menu[]=_('Prévision');  $desc[]=_('Prévision');
$menu[]=_('Export opérations rapprochées');  $desc[]=_('Export opérations rapprochées en CSV');
$menu[]=_('Administrateur');  $desc[]=_('Suivi des gérants, administrateurs et salariés');
$menu[]=_('Menu par défaut');  $desc[]=_('Configuration des menus par défaut');
$menu[]=_('Agenda');  $desc[]=_('Agenda');
?>
<?php 
$attr_def[]=_('Prix vente');
$attr_def[]=_('Prix achat');
$attr_def[]=_('Durée Amortissement');
$attr_def[]=_('Montant initial');
$attr_def[]=_('TVA non déductible');
$attr_def[]=_('TVA non déductible récupérable par l\'impôt');
$attr_def[]=_('Partie fiscalement non déductible');
$attr_def[]=_('Dépense  charge du grant (partie privé) ');
$attr_def[]=_('Compte bancaire');
$attr_def[]=_('Date début');
$attr_def[]=_('Nom');
$attr_def[]=_('Taux TVA');
$attr_def[]=_('Nom de la banque');
$attr_def[]=_('Description');
$attr_def[]=_('Personne de contact ');
$attr_def[]=_('numéro de tva ');
$attr_def[]=_('Adresse ');
$attr_def[]=_('pays ');
$attr_def[]=_('téléphone ');
$attr_def[]=_('email ');
$attr_def[]=_('Quick Code');
$attr_def[]=_('Ville');
$attr_def[]=_('Fax');
$attr_def[]=_('GSM');
$attr_def[]=_('code postal');
$attr_def[]=_('Numero de client');
$attr_def[]=_('Prénom');
$attr_def[]=_('Contrepartie pour TVA récup par impot');
$attr_def[]=_('Contrepartie pour TVA non Ded.');
$attr_def[]=_('Contrepartie pour dépense à charge du gérant');
$attr_def[]=_('Contrepartie pour dépense fiscal. non déd.');
$attr_def[]=_('Poste Comptable');
$attr_def[]=_('Date Fin');
$attr_def[]=_('Gestion stock');
$attr_def[]=_('Société');
?>
<?php 
$document_type[]=_('Document Interne');
$document_type[]=_('Bons de commande client');
$document_type[]=_('Bon de commande Fournisseur');
$document_type[]=_('Facture');
$document_type[]=_('Lettre de rappel');
$document_type[]=_('Courrier');
$document_type[]=_('Proposition');
$document_type[]=_('Email');
$document_type[]=_('Divers');
$document_type[]=_('Note de frais');
$document_type[]=_('Réception commande Fournisseur');
$document_type[]=_('Réception commande Client');
$document_type[]=_('Réception magazine');
?>
<?php 
$action[]=_('Ajout de fiche');
$action[]=_('Création, modification et effacement de fiche');
$action[]=_('création, modification et effacement de catégorie de fiche');
$action[]=_('Effacer les documents du suivi');
$action[]=_('Voir les documents du suivi');
$action[]=_('Modifier le type de document');
?>
<?php 
$mdp[]=_('Caisse');
$mdp[]=_('Paiement électronique');
$mdp[]=_('Caisse');
$mdp[]=_('Par gérant ou administrateur');
?>
<?php 
$jrn_def_name[]=_('Achat');
$jrn_def_name[]=_('Financier');
$jrn_def_name[]=_('Opération Diverses');
$jrn_def_name[]=_('Vente');
?>
<?php 
$jrn_def_description[]=_('Concerne tous les achats, factures reçues, notes de crédit reçues et notes de frais');
$jrn_def_description[]=_('Concerne tous les mouvements financiers (comptes en banque, caisses, visa...)');
$jrn_def_description[]=_('Concerne toutes les opérations comme les amortissements, les comptes TVA, ...');
$jrn_def_description[]=_('Concerne toutes les ventes, notes de crédit envoyées');
?>

==> noalyss-6.8.0.0.tar.gz: noalyss-6.8.0.0/include/database.item.php <==
<?php 
$menu[]=_('Export pièce PDF');  
$menu[]=_('Clef de répartition');  
$menu[]=_('Configuration extension');  
$menu[]=_('Achat');  $desc[]=_('Nouvel achat ou dépense');
$menu[]=_('Historique');  $desc[]=_('Historique des imputations analytiques');
$menu[]=_('Balance simple');  $desc[]=_('Balance simple des imputations analytiques');
$menu[]=_('Tableau');  $desc[]=_('Tableau lié à la comptabilité');
$menu[]=_('Balance Analytique/comptabilité');  $desc[]=_('Lien entre comptabilité et Comptabilité analytique');
$menu[]=_('Groupe');  $desc[]=_('Balance par groupe');
$menu[]=_('TVA');  $desc[]=_('Config. de la tva');
$menu[]=_('Vente');  $desc[]=_('Nouvelle vente ou recette');
$menu[]=_('Config. Menu');  $desc[]=_('Configuration des menus et plugins');
$menu[]=_('Fournisseur');  $desc[]=_('Suivi fournisseur');
$menu[]=_('Opérations diverses');  $desc[]=_('OD analytique');
$menu[]=_('Création de rapport');  $desc[]=_('Création de rapport');
$menu[]=_('saut de ligne');  $desc[]=_('Saut de ligne');
$menu[]=_('Client');  $desc[]=_('Suivi client');
$menu[]=_('Historique stock');  $desc[]=_('Historique des mouvement de stock');
$menu[]=_('Export Historique');  
$menu[]=_('Export Journaux');  
$menu[]=_('Export Journaux');  
$menu[]=_('Export Poste détail');  
$menu[]=_('Export Poste détail');  
$menu[]=_('Export Fiche détail');  
$menu[]=_('Export Fiche détail');  
$menu[]=_('Export Fiche balance');  
$menu[]=_('Export Fiche balance');  
$menu[]=_('Export report');  
$menu[]=_('Export report');  
$menu[]=_('Export Fiche');  
$menu[]=_('Export Fiche');  
$menu[]=_('Export Grand Livre');  
$menu[]=_('Export Grand Livre');  
$menu[]=_('Export Sécurité');  
$menu[]=_('Export Comptabilité analytique');  
$menu[]=_('Export Comptabilité analytique balance simple');  
$menu[]=_('Export Comptabilité analytique');  
$menu[]=_('Export Comptabilité analytique balance double');  
$menu[]=_('Export Comptabilité analytique balance double');  
$menu[]=_('Export Balance comptable');  
$menu[]=_('Export Balance comptable');  
$menu[]=_('Export Tableau Analytique');  
$menu[]=_('Export Historique Compt. Analytique');  
$menu[]=_('Export Balance groupe analytique');  
$menu[]=_('Export Bilan');  
$menu[]=_('Impression Grand-Livre');  
$menu[]=_('Export définition d\'un raport');  
$menu[]=_('Export Action Gestion');  
$menu[]=_('Export Historique mouvement stock');  
$menu[]=_('Export Résumé list stock');  
$menu[]=_('Plan Compt. analytique');  $desc[]=_('Plan analytique');
$menu[]=_('Groupe');  $desc[]=_('Groupe analytique');
$menu[]=_('Contact');  $desc[]=_('Liste des contacts');
$menu[]=_('Extension');  $desc[]=_('Extensions (plugins)');
$menu[]=_('Ecriture prédefinie');  $desc[]=_('Gestion des opérations prédéfinifies');
$menu[]=_('Opérations Diverses');  $desc[]=_('Nouvelle opérations diverses');
$menu[]=_('Nouvel extrait');  $desc[]=_('Nouvel extrait bancaire');
$menu[]=_('Recherche');  $desc[]=_('Recherche');
$menu[]=_('Paramètre');  $desc[]=_('Module paramètre');
$menu[]=_('Catégorie de documents');  $desc[]=_('Config. catégorie de documents');
$menu[]=_('Lettrage par Fiche');  $desc[]=_('Lettrage par fiche');
$menu[]=_('Historique achat');  $desc[]=_('Historique achat');
$menu[]=_('Historique opérations diverses');  $desc[]=_('Historique opérations diverses');
$menu[]=_('Poste');  $desc[]=_('Impression du détail d\'un poste comptable');
$menu[]=_('Rapport');  $desc[]=_('Impression de rapport');
$menu[]=_('Grand Livre');  $desc[]=_('Impression du grand livre');
$menu[]=_('Balance');  $desc[]=_('Impression des balances comptables');
$menu[]=_('Achat');  $desc[]=_('Menu achat');
$menu[]=_('Menu et profil');  $desc[]=_('Menu ');
$menu[]=_('Impression');  $desc[]=_('Menu impression');
$menu[]=_('Banque');  $desc[]=_('Information Banque');
$menu[]=_('Grand\'Livre');  $desc[]=_('Grand livre analytique');
$menu[]=_('Gestion');  $desc[]=_('Module gestion');
$menu[]=_('Lettrage');  $desc[]=_('Lettrage');
$menu[]=_('Accueil');  $desc[]=_('Accueil');
$menu[]=_('Comptabilité');  $desc[]=_('Module comptabilité');
$menu[]=_('Divers');  $desc[]=_('Paramètres divers');
$menu[]=_('Sortie');  $desc[]=_('Sortie');
$menu[]=_('Profil');  $desc[]=_('Configuration profil');
$menu[]=_('Poste');  $desc[]=_('Config. poste comptable de base');
$menu[]=_('Fiche');  $desc[]=_('Liste,Balance,Historique par fiche');
$menu[]=_('Préférence');  $desc[]=_('Préférence');
$menu[]=_('Configuration étiquette');  $desc[]=_('Configuration des tags');
$menu[]=_('Balance croisée double');  $desc[]=_('Balance double croisées des imputations analytiques');
$menu[]=_('Sociétés');  $desc[]=_('Parametre societe');
$menu[]=_('Période');  $desc[]=_('Gestion des périodes');
$menu[]=_('Vérification ');  $desc[]=_('Vérification de la comptabilité');
$menu[]=_('Ecriture Ouverture');  $desc[]=_('Ecriture d\'ouverture');
$menu[]=_('Document');  $desc[]=_('Config. modèle de document');
$menu[]=_('journaux');  $desc[]=_('Configuration des journaux');
$menu[]=_('Sécurité');  $desc[]=_('configuration de la sécurité');
$menu[]=_('Attribut de fiche');  $desc[]=_('Gestion des attributs de fiches ');
$menu[]=_('Etat des stock');  $desc[]=_('Etat des stock');
$menu[]=_('Modification Stocks');  $desc[]=_('Modification des stocks (inventaire)');
$menu[]=_('Histo. Changement');  $desc[]=_('Liste des changements manuels des stocks');
$menu[]=_('Navigateur');  $desc[]=_('Menu simplifié pour retrouver rapidement un menu');
$menu[]=_('Recherche');  $desc[]=_('Recherche');
$menu[]=_('Historique');  $desc[]=_('Historique');
$menu[]=_('Rapprochement');  $desc[]=_('Rapprochement bancaire');
$menu[]=_('Soldes');  $desc[]=_('Solde des comptes en banques, caisse...');
$menu[]=_('Lettrage par Poste');  $desc[]=_('lettrage par poste comptable');
$menu[]=_('Balance');  $desc[]=_('Balance par catégorie de fiche');
$menu[]=_('Plan Comptable');  $desc[]=_('Config. du plan comptable');
$menu[]=_('Historique vente');  $desc[]=_('Historique des ventes');
$menu[]=_('Historique financier');  $desc[]=_('Historique financier');
$menu[]=_('Rapprochement');  $desc[]=_('Impression des rapprochements');
$menu[]=_('Bilan');  $desc[]=_('Impression de bilan');
$menu[]=_('Configuration des dépôts');  $desc[]=_('Configuration dépôts');
$menu[]=_('Stock');  $desc[]=_('Stock');
$menu[]=_('Catégorie de fiche');  $desc[]=_('Gestion catégorie de fiche');
$menu[]=_('Fiche');  $desc[]=_('Configuration de catégorie de fiches');
$menu[]=_('Etat des documents');  $desc[]=_('Etat des documents');
$menu[]=_('Opérations diverses');  $desc[]=_('Menu opérations diverses');
$menu[]=_('Impression Journaux');  $desc[]=_('Impression des journaux');
$menu[]=_('Vente / Recette');  $desc[]=_('Menu ventes et recettes');
$menu[]=_('Impression');  $desc[]=_('Impression compta. analytique');
$menu[]=_('Compta Analytique');  $desc[]=_('Module comptabilité analytique');
$menu[]=_('Tableau de bord');  $desc[]=_('Tableau de bord');
$menu[]=_('Avancé');  $desc[]=_('Menu avancé');
$menu[]=_('Favori');  $desc[]=_('Raccourci vers vos menus préférés');
$menu[]=_('Trésorerie');  $desc[]=_('Menu Financier');
$menu[]=_('Liste Suivi');  $desc[]=_('Document de suivi sous forme de liste');
$menu[]=_('Moyen de paiement');  $desc[]=_('Config. des méthodes de paiement');
$menu[]=_('Administration');  $desc[]=_('Suivi administration, banque');
$menu[]=_('Prévision');  $desc[]=_('Prévision');
$menu[]=_('Export opérations rapprochées');  $desc[]=_('Export opérations rapprochées en CSV');
$menu[]=_('Administrateur');  $desc[]=_('Suivi des gérants, administrateurs et salariés');
$menu[]=_('Menu par défaut');  $desc[]=_('Configuration des menus par défaut');
$menu[]=_('Agenda');  $desc[]=_('Agenda');
?>
<?php 
$attr_def[]=_('Prix vente');
$attr_def[]=_('Prix achat');
$attr_def[]=_('Durée Amortissement');
$attr_def[]=_('Montant initial');
$attr_def[]=_('TVA non déductible');
$attr_def[]=_('TVA non déductible récupérable par l\'impôt');
$attr_def[]=_('Partie fiscalement non déductible');
$attr_def[]=_('Dépense  charge du grant (partie privé) ');
$attr_def[]=_('Compte bancaire');
$attr_def[]=_('Date début');
$attr_def[]=_('Nom');
$attr_def[]=_('Taux TVA');
$attr_def[]=_('Nom de la banque');
$attr_def[]=_('Description');
$attr_def[]=_('Personne de contact ');
$attr_def[]=_('numéro de tva ');
$attr_def[]=_('Adresse ');
$attr_def[]=_('pays ');
$attr_def[]=_('téléphone ');
$attr_def[]=_('email ');
$attr_def[]=_('Quick Code');
$attr_def[]=_('Ville');
$attr_def[]=_('Fax');
$attr_def[]=_('GSM');
$attr_def[]=_('code postal');
$attr_def[]=_('Numero de client');
$attr_def[]=_('Prénom');
$attr_def[]=_('Contrepartie pour TVA récup par impot');
$attr_def[]=_('Contrepartie pour TVA non Ded.');
$attr_def[]=_('Contrepartie pour dépense à charge du gérant');
$attr_def[]=_('Contrepartie pour dépense fiscal. non déd.');
$attr_def[]=_('Poste Comptable');
$attr_def[]=_('Date Fin');
$attr_def[]=_('Gestion stock');
$attr_def[]=_('Société');
?>
<?php 
$document_type[]=_('Document Interne');
$document_type[]=_('Bons de commande client');
$document_type[]=_('Bon de commande Fournisseur');
$document_type[]=_('Facture');
$document_type[]=_('Lettre de rappel');
$document_type[]=_('Courrier');
$document_type[]=_('Proposition');
$document_type[]=_('Email');
$document_type[]=_('Divers');
$document_type[]=_('Note de frais');
$document_type[]=_('Réception commande Fournisseur');
$document_type[]=_('Réception commande Client');
$document_type[]=_('Réception magazine');
?>
<?php 
$action[]=_('Ajout de fiche');
$action[]=_('Création, modification et effacement de fiche');
$action[]=_('création, modification et effacement de catégorie de fiche');
$action[]=_('Effacer les documents du suivi');
$action[]=_('Voir les documents du suivi');
$action[]=_('Modifier le type de document');
?>
<?php 
$mdp[]=_('Caisse');
$mdp[]=_('Paiement électronique');
$mdp[]=_('Caisse');
$mdp[]=_('Par gérant ou administrateur');
?>
<?php 
$jrn_def_name[]=_('Achat');
$jrn_def_name[]=_('Financier');
$jrn_def_name[]=_('Opération Diverses');
$jrn_def_name[]=_('Vente');
?>
<?php 
$jrn_def_description[]=_('Concerne tous les achats, factures reçues, notes de crédit reçues et notes de frais');
$jrn_def_description[]=_('Concerne tous les mouvements financiers (comptes en banque, caisses, visa...)');
$jrn_def_description[]=_('Concerne toutes les opérations comme les amortissements, les comptes TVA, ...');
$jrn_def_description[]=_('Concerne toutes les ventes, notes de crédit envoyées');
?>
